# civic-scraper

Tools for downloading agendas, minutes and other documents produced by local government

## Documentation

```{toctree}
:glob:
:maxdepth: 1

install
usage
advanced_config
contributing
releasing
reference
```

## Links

- Documentation: <http://civic-scraper.readthedocs.io/en/latest/>
- GitHub: <https://github.com/biglocalnews/civic-scraper>
- PyPI: <https://pypi.python.org/pypi/civic-scraper>
